@@ -479,29 +479,29 @@ int do_lock_lv(unsigned char command, unsigned char lock_flags, char *resource)
 
 	cmd->partial_activation = (lock_flags & LCK_PARTIAL_MODE) ? 1 : 0;
 
-	switch (command) {
-	case LCK_LV_EXCLUSIVE & LCK_MASK:
+	switch (command & LCK_MASK) {
+	case LCK_LV_EXCLUSIVE:
 		status = do_activate_lv(resource, lock_flags, LKM_EXMODE);
 		break;
 
-	case LCK_LV_SUSPEND & LCK_MASK:
+	case LCK_LV_SUSPEND:
 		status = do_suspend_lv(resource);
 		if (!status)
 			suspended++;
 		break;
 
 	case LCK_UNLOCK:
-	case LCK_LV_RESUME & LCK_MASK:	/* if active */
+	case LCK_LV_RESUME:	/* if active */
 		status = do_resume_lv(resource);
 		if (!status)
 			suspended--;
 		break;
 
-	case LCK_LV_ACTIVATE & LCK_MASK:
+	case LCK_LV_ACTIVATE:
 		status = do_activate_lv(resource, lock_flags, LKM_CRMODE);
 		break;
 
-	case LCK_LV_DEACTIVATE & LCK_MASK:
+	case LCK_LV_DEACTIVATE:
 		status = do_deactivate_lv(resource, lock_flags);
 		break;
 
