@@ -21,6 +21,9 @@ pvcreate --metadatacopies 0 $dev3
 vgcreate $vg --physicalextentsize 8.00M $dev1 $dev2 
 check_vg_field_ $vg vg_extent_size 8.00M 
 vgremove $vg
+# try vgck and to remove it again - should fail (but not segfault)
+not vgremove $vg
+not vgck $vg
 
 #COMM 'vgcreate accepts smaller (128) maxlogicalvolumes for VG'
 vgcreate $vg --maxlogicalvolumes 128 $dev1 $dev2 
@@ -69,9 +72,6 @@ not vgcreate $vg $dev3
 
 # Test default (4MB) vg_extent_size as well as limits of extent_size
 not vgcreate --physicalextentsize 0K $vg $dev1 $dev2
-vgcreate $vg $dev1 $dev2
-check_vg_field_ $vg vg_extent_size 4.00M
-vgremove -ff $vg
 vgcreate --physicalextentsize 1K $vg $dev1 $dev2
 check_vg_field_ $vg vg_extent_size 1.00K
 vgremove -ff $vg
@@ -79,3 +79,11 @@ not vgcreate --physicalextentsize 3K $vg $dev1 $dev2
 not vgcreate --physicalextentsize 1024T $vg $dev1 $dev2
 #not vgcreate --physicalextentsize 1T $vg $dev1 $dev2
 # FIXME: vgcreate allows physicalextentsize larger than pv size!
+
+# Test default max_lv, max_pv, extent_size, alloc_policy, clustered
+vgcreate $vg $dev1 $dev2
+check_vg_field_ $vg vg_extent_size 4.00M
+check_vg_field_ $vg max_lv 0
+check_vg_field_ $vg max_pv 0
+check_vg_field_ $vg vg_attr "wz--n-"
+vgremove -ff $vg
