@@ -20,9 +20,6 @@ static int vgdisplay_single(struct cmd_context *cmd, const char *vg_name,
 			    void *handle __attribute((unused)))
 {
 	/* FIXME Do the active check here if activevolumegroups_ARG ? */
-	if (vg_read_error(vg))
-		return ECMD_FAILED;
-
 	vg_check_status(vg, EXPORTED_VG);
 
 	if (arg_count(cmd, colon_ARG)) {
